# seaborn.axes_style

```py
seaborn.axes_style(style=None, rc=None)
```

Return a parameter dict for the aesthetic style of the plots.

This affects things like the color of the axes, whether a grid is enabled by default, and other aesthetic elements.

This function returns an object that can be used in a `with` statement to temporarily change the style parameters.

参数：`style`：dict, None, or one of {darkgrid, whitegrid, dark, white, ticks}

> A dictionary of parameters or the name of a preconfigured set.

`rc`：dict, optional

> Parameter mappings to override the values in the preset seaborn style dictionaries. This only updates parameters that are considered part of the style definition.



See also

set the matplotlib parameters for a seaborn themereturn a parameter dict to to scale plot elementsdefine the color palette for a plot

Examples

```py
>>> st = axes_style("whitegrid")

```

```py
>>> set_style("ticks", {"xtick.major.size": 8, "ytick.major.size": 8})

```

```py
>>> import matplotlib.pyplot as plt
>>> with axes_style("white"):
...     f, ax = plt.subplots()
...     ax.plot(x, y)               

```